@@ -8,25 +8,48 @@ use warnings;
 use Error qw(:try);
 use WebService::Cmis::ClientException ();
 
+my $connection = $ENV{CMIS_CONNECTION} || $WebService::Cmis{DefaultConnection};
+diag("connection = '$connection' ... set the enviromnent variable CMIS_CONNECTION to a different to test against a different backend");
+
+
 sub test_login : Test(1) {
   my $this = shift;
 
   my $client = $this->getClient;
+  my $ticket = $client->login;
 
-  ok($client->{ticket} || !defined($client->{loginUrl}));
+  ok(defined $ticket);
 }
 
+sub test_logout : Test(1) {
+  my $this = shift;
+
+  my $client = $this->getClient;
+  my $ticket = $client->login;
+
+  ok(defined $ticket);
+
+  $client->logout;
+  $this->{client} = undef;
+
+  # SMELL: how can we test we are logged out?
+}
+
+
 sub test_reuse_ticket : Test(2) {
   my $this = shift;
     
   my $client1 = $this->getClient;
-  my $ticket1 = $client1->{ticket};
+  my $ticket1 = $client1->login;
 
   SKIP: {
     skip "no ticket authentication", 2 unless $ticket1;
 
-    my $client2 = $this->getClient()->login(ticket=>$ticket1);
-    my $ticket2 = $client2->{ticket};
+    note("ticket1=$ticket1");
+
+    my $client2 = $this->getClient();
+    my $ticket2 = $client2->login(ticket=>$ticket1);
+    note("ticket2=$ticket2");
 
     ok($ticket2);
 
@@ -53,19 +76,6 @@ sub test_cant_reuse_after_logout : Test(1) {
   ok($error, "we should not be able to use the client after having logged out");
 }
 
-sub test_logout : Test(2) {
-  my $this = shift;
-
-  my $client = $this->getClient;
-
-  ok($client->{ticket} || !defined($client->{logoutUrl}));
-
-  $client->logout;
-  $this->{client} = undef;
-
-  ok(!defined $client->{ticket} || !defined($client->{logoutUrl}));
-}
-
 sub test_Client_getRepositories : Test(3) {
   my $this = shift;
 
