@@ -51,7 +51,7 @@ sub toString {
   my $this = shift;
 
   my $result = $this->{principalId}." is allowed to ";
-  $result .= $_ foreach sort @{$this->{permissions}};
+  $result .= join(", ", sort @{$this->{permissions}});
   $result .= " (direct=".$this->{direct}.")";
 }
 
@@ -59,7 +59,7 @@ sub toString {
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2012 Michael Daum
+Copyright 2012-2013 Michael Daum
 
 This module is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.  See F<http://dev.perl.org/licenses/artistic.html>.
